@@ -28,34 +28,34 @@ def main():
     if not project_path:
         exit(0)
 
-    package_name = 'paraty_commit'
+    package_name = 'paraty_commit_python2'
     package_path = pkg_resources.resource_filename(package_name, '')
 
     files = os.listdir(package_path)
     files = [file for file in files if file in FILES_TO_COPY]
     files = [file for file in files if os.path.isfile(os.path.join(package_path, file))]
 
-    print(Style.BRIGHT + Fore.GREEN + f"Package Path: {package_path}")
-    print(Style.BRIGHT + Fore.GREEN + f"Project Path: {project_path}")
+    print(Style.BRIGHT + Fore.GREEN + "Package Path: " + package_path)
+    print(Style.BRIGHT + Fore.GREEN + "Project Path: " + project_path)
 
     for file in files:
         file_name_path = os.path.join(package_path, file)
         file_name_project_path = os.path.join(project_path, file)
         shutil.copy(file_name_path, file_name_project_path)
-        print(Fore.GREEN + f"Added file: {file}")
+        print(Fore.GREEN + "Added file: " + file)
 
-    execute_command("python3 -m pip install pre-commit==2.9.2")
+    execute_command("python2 -m pip install pre-commit==1.21.0")
     print('find "'+project_path+'" -type f -name ".pre-commit-config.yaml" -exec git add {} \;')
     execute_command('find "'+project_path+'" -type f -name ".pre-commit-config.yaml" -exec git add {} \;')
     execute_command("pre-commit autoupdate --bleeding-edge")
     execute_command("pre-commit install")
-    execute_command("python3 -m pip install pylint==2.15.10")
+    execute_command("python2 -m pip install pylint==1.9.5")
 
     print(Style.BRIGHT + Fore.GREEN + "Paraty Pre-Commit Installed!!")
 
 
 def execute_command(comando):
-    print(Style.BRIGHT + Fore.GREEN + f">> {comando}")
+    print(Style.BRIGHT + Fore.GREEN + ">> " + comando)
     proceso = subprocess.Popen(comando, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     salida_stdout, salida_stderr = proceso.communicate()
     codigo_salida = proceso.returncode
